package com.example.sybd.services;

import com.example.sybd.models.Client;
import com.example.sybd.models.Post;
import com.example.sybd.repository.ClientRepository;
import com.example.sybd.utils.mappingUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class ClientService implements IService<Client, Long> {
	private final ClientRepository clientRepository;

	public ClientService(ClientRepository clientRepository) {
		this.clientRepository = clientRepository;
	}

	public Client create(@NotNull String name,
	                     @NotNull String secondName,
	                     @NotNull String lastName,
	                     @NotNull String telephone,
	                     @NotNull String address) {
		Client client = new Client();
		client.setName(name);
		client.setSecondName(secondName);
		client.setLastName(lastName);
		client.setAddress(address);
		client.setTelephone(telephone);
		return clientRepository.save(client);
	}

	@Override
	public @NotNull List<Client> all() {
		return mappingUtils.iterableToList(clientRepository.findAll());
	}

	@Override
	public @Nullable Client get(Long id) {
		return clientRepository.findById(id).orElse(null);
	}

	@Override
	public @Nullable Client delete(Long id) {
		Client client = clientRepository.findById(id).orElse(null);
		if (client == null) return null;
		clientRepository.deleteById(id);
		return client;
	}

	@Override
	public @Nullable Client update(Client other) {
		Client client = clientRepository.findById(other.getId()).orElse(null);
		if (client == null) return null;

		client.setName(other.getName());
		client.setSecondName(other.getSecondName());
		client.setLastName(other.getLastName());
		client.setAddress(other.getAddress());
		client.setTelephone(other.getTelephone());

		return clientRepository.save(client);
	}
}
