package com.example.sybd.services;

import com.example.sybd.models.Post;
import com.example.sybd.models.ServiceGroup;
import com.example.sybd.repository.PostRepository;
import com.example.sybd.utils.mappingUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class PostService implements IService<Post, Long> {
	private final PostRepository postRepository;
	private final GroupServiceService groupServiceService;

	public PostService(PostRepository postRepository, GroupServiceService groupServiceService) {
		this.postRepository = postRepository;
		this.groupServiceService = groupServiceService;
	}

	public Post create(@NotNull String name, @NotNull Long group_id) {
		ServiceGroup serviceGroup = groupServiceService.get(group_id);
		if (serviceGroup == null)
			return null;

		Post out = new Post();
		out.setName(name);
		out.setGroup(serviceGroup);

		return postRepository.save(out);
	}

	@Override
	public @NotNull List<Post> all() {
		return mappingUtils.iterableToList(postRepository.findAll());
	}

	@Override
	public @Nullable Post get(Long id) {
		return postRepository.findById(id).orElse(null);
	}

	@Override
	public @Nullable Post delete(Long id) {
		Post post = postRepository.findById(id).orElse(null);
		if (post == null) return null;
		postRepository.deleteById(id);
		return post;
	}

	@Override
	public @Nullable Post update(Post other) {
		Post post = postRepository.findById(other.getId()).orElse(null);
		if (post == null) return null;

		if (other.getName() != null)
			post.setName(other.getName());
		if (other.getGroup() != null)
			post.setGroup(other.getGroup());

		return postRepository.save(post);
	}
}
