package com.example.sybd.services;

import com.example.sybd.models.Service;
import com.example.sybd.models.ServiceGroup;
import com.example.sybd.repository.ServiceRepository;
import com.example.sybd.utils.mappingUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.List;

@org.springframework.stereotype.Service
public class ServicesService implements IService<Service, Long> {
	private final ServiceRepository serviceRepository;
	private final GroupServiceService groupServiceService;

	public ServicesService(ServiceRepository serviceRepository, GroupServiceService groupServiceService) {
		this.serviceRepository = serviceRepository;
		this.groupServiceService = groupServiceService;
	}

	public Service create(@NotNull String name, @NotNull Integer cost, @NotNull Long group_id) {
		ServiceGroup serviceGroup = groupServiceService.get(group_id);
		if (serviceGroup == null)
			return null;

		Service service = new Service();
		service.setName(name);
		service.setCost(cost);
		service.setGroup(serviceGroup);

		return serviceRepository.save(service);
	}

	@Override
	public @NotNull List<Service> all() {
		return mappingUtils.iterableToList(serviceRepository.findAll());
	}

	@Override
	public @Nullable Service get(Long id) {
		return serviceRepository.findById(id).orElse(null);
	}

	@Override
	public @Nullable Service delete(Long id) {
		Service service = serviceRepository.findById(id).orElse(null);
		if (service == null)
			return null;
		serviceRepository.deleteById(id);
		return service;
	}

	@Override
	public @Nullable Service update(Service other) {
		Service service = serviceRepository.findById(other.getId()).orElse(null);
		if (service == null)
			return null;

		service.setName(other.getName());
		service.setCost(other.getCost());
		service.setGroup(other.getGroup());

		return serviceRepository.save(service);
	}
}
