package com.example.sybd.services;

import com.example.sybd.models.Client;
import com.example.sybd.models.Service;
import com.example.sybd.models.Visit;
import com.example.sybd.models.Worker;
import com.example.sybd.repository.ClientRepository;
import com.example.sybd.repository.VisitRepository;
import com.example.sybd.utils.mappingUtils;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.sql.Date;
import java.sql.Time;
import java.util.List;

@org.springframework.stereotype.Service
public class VisitService implements IService<Visit, Long> {
	private final VisitRepository visitRepository;
	private final ClientService clientService;
	private final WorkerService workerService;
	private final ServicesService servicesService;

	public VisitService(VisitRepository visitRepository,
	                    ClientService clientService,
	                    WorkerService workerService,
	                    ServicesService servicesService) {
		this.visitRepository = visitRepository;
		this.clientService = clientService;
		this.workerService = workerService;
		this.servicesService = servicesService;
	}

	public Visit create(@NotNull Long client_id,
	                    @NotNull Long service_id,
	                    @NotNull Long worker_id,
	                    @NotNull Date date,
	                    @NotNull Time time) {
		Client client = clientService.get(client_id);
		if (client == null)
			return null;
		Service service = servicesService.get(service_id);
		if (service == null)
			return null;
		Worker worker = workerService.get(worker_id);
		if (worker == null)
			return null;
		Visit visit = new Visit();
		visit.setClient(client);
		visit.setService(service);
		visit.setWorker(worker);
		visit.setDateVisit(date);
		visit.setTime(time);

		return visitRepository.save(visit);
	}

	@Override
	public @NotNull List<Visit> all() {
		return mappingUtils.iterableToList(visitRepository.findAll());
	}

	@Override
	public @Nullable Visit get(Long id) {
		return visitRepository.findById(id).orElse(null);
	}

	@Override
	public @Nullable Visit delete(Long id) {
		Visit visit = visitRepository.findById(id).orElse(null);
		if (visit == null)
			return null;

		visitRepository.deleteById(id);
		return visit;
	}

	@Override
	public @Nullable Visit update(Visit other) {
		Visit visit = visitRepository.findById(other.getId()).orElse(null);
		if (visit == null)
			return null;

		visit.setEnded(other.isEnded());

		return visitRepository.save(visit);
	}
}
